==> org-lsst-ccs-subsystem-fcs-main-6.1.8-sources.jar: org/lsst/ccs/subsystems/fcs/simulation/SimuPlutoGateway.java <==

package org.lsst.ccs.subsystems.fcs.simulation;

import org.lsst.ccs.framework.HasLifecycle;
import org.lsst.ccs.subsystems.fcs.drivers.PlutoGateway;
import org.lsst.ccs.subsystems.fcs.utils.FcsUtils;
import org.lsst.ccs.subsystems.fcs.DigitalSensor;

/**
 * This class simulates the Can Open Pluto Gateway we use to communicate with
 * the sensors in the whole size prototype. It provides a method to force a
 * sensor to be on or off in order to be able to simulate hardware state. For
 * example, if we set to on the handoff position sensors on autochanger, we can
 * simulate that autochanger trucks are at HANDOFF position.
 *
 * @author virieux
 */
public class SimuPlutoGateway extends PlutoGateway implements HasLifecycle {

    @Override
    public boolean isInitialized() {
        return true;
    }

    /**
     * returns simulated readValues for the gateway. In simulation we don't have a
     * real gateway to read but we can force the readValues to simulate various
     * hardware states.
     *
     * @return simulated readValues
     */
    @Override
    public int[] readNewValues() {
        return readValues;
    }

    /**
     * Replace simulated device values in order to force simulated sensor to be on
     * or off depending on the argument on given as argument.
     *
     * @param sensor to be changed
     * @param on     if true, simulates that sensor is on, else simulates that
     *               sensor if off.
     */
    public synchronized void replaceSensorValue(DigitalSensor sensor, boolean on) {
        int byteNo = sensor.getByteNumero();
        int value = this.readValues[byteNo];
        int newValue;
        if (on) {
            newValue = FcsUtils.force2one(value, sensor.getInputNumero());
        } else {
            newValue = FcsUtils.force2zero(value, sensor.getInputNumero());
        }
        this.readValues[byteNo] = newValue;
    }

}

==> org-lsst-ccs-subsystem-fcs-main-8.3.0-sources.jar: org/lsst/ccs/subsystems/fcs/simulation/SimuPlutoGateway.java <==

package org.lsst.ccs.subsystems.fcs.simulation;

import org.lsst.ccs.subsystems.fcs.drivers.PlutoGateway;
import org.lsst.ccs.subsystems.fcs.utils.FcsUtils;
import org.lsst.ccs.subsystems.fcs.DigitalSensor;

/**
 * This class simulates the Can Open Pluto Gateway we use to communicate with
 * the sensors in the whole size prototype. It provides a method to force a
 * sensor to be on or off in order to be able to simulate hardware state. For
 * example, if we set to on the handoff position sensors on autochanger, we can
 * simulate that autochanger trucks are at HANDOFF position.
 *
 * @author virieux
 */
public class SimuPlutoGateway extends PlutoGateway {

    @Override
    public boolean isInitialized() {
        return true;
    }

    /**
     * returns simulated readValues for the gateway. In simulation we don't have a
     * real gateway to read but we can force the readValues to simulate various
     * hardware states.
     *
     * @return simulated readValues
     */
    @Override
    public int[] readNewValues() {
        return readValues;
    }

    /**
     * Replace simulated device values in order to force simulated sensor to be on
     * or off depending on the argument on given as argument.
     *
     * @param sensor to be changed
     * @param on     if true, simulates that sensor is on, else simulates that
     *               sensor if off.
     */
    public synchronized void replaceSensorValue(DigitalSensor sensor, boolean on) {
        int byteNo = sensor.getByteNumero();
        int value = this.readValues[byteNo];
        int newValue;
        if (on) {
            newValue = FcsUtils.force2one(value, sensor.getInputNumero());
        } else {
            newValue = FcsUtils.force2zero(value, sensor.getInputNumero());
        }
        this.readValues[byteNo] = newValue;
    }

}
